<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="ru" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Категория:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Запустить торрент</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Пропустить проверку хеша</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Создать подпапку</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Режим управления торрентом:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Без категории</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Добавить категорию…</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Удалить категорию</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Удалить пустые категории</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Возобновить торренты</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Остановить торренты</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Удалить торренты</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Новая категория</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Изменить категорию…</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Выйти из qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Только одна ссылка на строку</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Общее ограничение соотношения отдачи должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Общее ограничение соотношения загрузки должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Другое ограничение соотношения отдачи должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Другое ограничение соотношения загрузки должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Максимальное число активных загрузок должно быть больше -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Максимальное число активных отдач должно быть больше -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Максимальное число активных торрентов должно быть больше -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Максимальное число соединений должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Максимальное число соединений на торрент должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Максимальное число слотов отдачи на торрент должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Не удалось сохранить настройки, возможно, qBittorrent недоступен.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent на Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Рейтинг должен быть в диапазоне от 0 до 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Ограничение времени раздачи должно быть в диапазоне от 0 до 525600 минут.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Порт для входящих соединений должен принимать значения от 1 до 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Порт для для веб-интерфейса должен принимать значения от 1 до 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Не удалось войти, возможно, qBittorrent недоступен.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Неверное имя пользователя или пароль.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Войти</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Авторы</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Отдавать торренты</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Путь сохранения по умолчанию:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Куки (cookie):</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Укажите папку здесь</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Подробнее</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Сведения о сертификатах</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Переместить</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Ограничение скорости отдачи</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Ограничение скорости загрузки</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Переименовать торрент</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Другой…</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Понедельник</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Вторник</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Среда</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Четверг</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Пятница</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Суббота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Воскресение</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Загрузить торренты по их адресам или магнет-ссылкам</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Загрузить локальный торрент</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Вы уверены, что хотите удалить выделенные торренты из списка?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Клиент qBittorrent недоступен</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Общее ограничение соотношения отдачи должно быть больше 0 или отключено.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Недопустимое название категории:\nПожалуйста, не используйте специальные символы в названии.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Не удалось создать категорию</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Порог скорости отдачи должен быть больше 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Свободно: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Таймер бездействия торрента должен быть больше 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Управление сохранением</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Порог скорости загрузки должен быть больше 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent выключен</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Настройки…</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Возобновить</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Низший приоритет</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Высший приоритет</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Понизить приоритет</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Повысить приоритет</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Панель статуса</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Скорость в заголовке</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Пожертвовать!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Возобновить все</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О qBittorrent</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Остановить все</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Добавить торрент-файл…</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Документация</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Добавить ссылку на торрент…</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Ограничение скорости отдачи</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Ограничение скорости загрузки</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Вы действительно хотите выйти из qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[З: %1, О: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Другие ограничения скорости</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Поисковый движок</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Фильтр торрентов…</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Торренты</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Загрузки</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Скорость</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Веб-интерфейс</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Язык интерфейса:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Оповещать об окончании загрузки по почте</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Запустить внешнюю программу по окончании загрузки торрента</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Фильтрация по IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Запланировать использование других ограничений скорости</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Очерёдность торрентов</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Отдавать торренты, пока их время раздачи не достигнет</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Автоматически добавлять эти трекеры к новым загрузкам:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Веб-интерфейс (удалённое управление)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-адрес:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Домены сервера:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Использовать HTTPS вместо HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Пропускать аутентификацию клиентов для localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Пропускать аутентификацию клиентов для разрешённых подсетей</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Обновлять динамическое доменное имя</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Хранить незавершённые торренты в:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Копировать торрент-файлы в:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Копировать торрент-файлы завершённых загрузок в:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Предварительно резервировать место для всех файлов</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Добавлять расширение .!qB к незавершённым файлам</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Автоматически добавлять торренты из:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-сервер:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Этот сервер требует защищённого соединения (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Используемый протокол:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP и μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Прослушиваемый порт</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Порт для входящих соединений:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Использовать UPnP / NAT-PMP маршрутизатора</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Использовать случайный порт при запуске</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Ограничения соединений</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Максимальное число соединений на торрент:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Общее ограничение числа соединений:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Максимальное число слотов отдачи на торрент:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Общее ограничение слотов отдачи:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Прокси-сервер</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(нет)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Использовать прокси для соединения с пирами</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Не использовать протоколы, неподдерживаемые прокси-сервером</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Использовать прокси только для торрентов</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Путь к фильтрам (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Адреса IP, запрещённые вручную…</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Применить к трекерам</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Общие ограничения скорости</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Отдача:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Загрузка:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Другие ограничения скорости</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>От кого:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Кому:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Когда:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Каждый день</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Будни</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Выходные</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Настройки ограничения скорости</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Применять ограничения скорости к служебному трафику</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Применять ограничения скорости к протоколу µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Приватность</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Включить DHT (децентрализованную сеть) для поиска пиров</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Включить обмен пирами (PeX)</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Включить обнаружение локальных пиров</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Режим шифрования:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Предпочитать шифрование</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Требовать шифрование</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Отключить шифрование</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Включить анонимный режим</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Максимальное число активных загрузок:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Максимальное число активных отдач:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Максимальное число активных торрентов:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Не учитывать количество медленных торрентов в этих ограничениях</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Ограничение рейтинга</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Отдавать торренты, пока их рейтинг не достигнет</translation>
    </message>
    <message>
        <source>then</source>
        <translation>затем</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Использовать UPnP / NAT-PMP для проброса портов через маршрутизатор</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Сертификат:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Ключ:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Регистрация</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Доменное имя:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Поддерживаемые параметры (с учётом регистра):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Имя торрента</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Категория</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Метки (разделённые запятыми)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Папка содержимого (та же, что и корневая папка для множественных торрентов)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Корневая папка (главный путь для подкаталога торрента)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Путь сохранения</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Количество файлов</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Размер торрента (в байтах)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Текущий трекер</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Хеш-сумма</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Подсказка: Включите параметр в кавычки для защиты от обрезки на пробелах (напр. "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Имя пользователя веб-интерфейса должно содержать не менее 3 символов.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Пароль веб-интерфейса должен быть не менее 6 символов.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>минут</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>КБ/с</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Включить защиту от кликджекинга</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Включить защиту от межсайтовой подделки запроса (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Удалять .torrent файлы позже</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Ограничение скорости загрузки:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Ограничение скорости отдачи:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Изменить текущий пароль</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Использовать альтернативный веб-интерфейс</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Путь сохранения по умолчанию:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Расположение файлов альтернативного веб-интерфейса не может быть пустым.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Не начинать загрузку автоматически</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Переключить торрент в Ручной режим</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>При изменении категории торрента:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Переместить затронутые торренты</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Применять ограничение скорости к локальным пирам</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 означает безлимитно</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Переместить торрент</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>При изменении пути сохранения по умолчанию:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Включить проверку заголовка хоста</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>При изменении пути сохранения категории:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Создать подпапку для торрентов с множеством файлов</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Переключить затронутые торренты в Ручной режим</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Расположение файлов:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Таймер бездействия торрента:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Режим управления торрентом по умолчанию:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>При добавлении торрента</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Флаги</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Клиент</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Прогресс</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Скорость загрузки</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Скорость отдачи</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Загружено</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Отдано</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Соответствие</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Файлы</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Страна</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Обычный</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Высокий</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Максимальный</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Трекеры</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Пиры</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Веб-сиды</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Файлы</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Загружено:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Торрент</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Активен:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Осталось времени:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Отдано:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Сиды:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Загрузка:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Отдача:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Пиры:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Огр. загрузки:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Огр. отдачи:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Потеряно:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Соединения:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Комментарий:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Рейтинг:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Следующий анонс:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Замечен целиком:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Общий размер:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Части:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Создан в:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Дата добавления:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Завершён:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Дата создания:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Хеш торрента:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Путь сохранения:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (из них есть %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 за сеанс)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 макс.)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 всего)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 сред.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Огр. загрузки:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Огр. отдачи:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Папка для наблюдения</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Переопределить путь сохранения</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Папка для наблюдения</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Путь сохранения по умолчанию</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>КБ/с</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Статистика пользователя</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Кэш</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Попаданий в кэш чтения:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Среднее время простоя в очереди: </translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Подключённые пиры:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Общий рейтинг:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Всего загружено:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Потеряно за сеанс:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Всего отдано:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Общий размер буфера:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Производительность</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Операций ввода/вывода в очереди:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Перегрузка кэша записи:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Перегрузка кэша чтения:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Общий размер очереди:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 узлов</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Все (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Загружаются (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Раздаются (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Завершены (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Возобновлены (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Остановлены (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Активны (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Неактивны (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>С ошибкой (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Все (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Загружаются (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Раздаются (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Завершены (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Остановлены (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Возобновлены (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Активны (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Неактивны (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>С ошибкой (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Прогресс</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Приоритет</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Осталось</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Доступно</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Прогресс</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Сиды</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Пиры</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Загрузка</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Отдача</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Рейтинг</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Осталось времени</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категория</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Метки</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Дата добавления</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Завершён</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Трекер</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Огр. загрузки</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Огр. отдачи</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Загружено</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Отдано</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Загружено за сеанс</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Отдано за сеанс</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Осталось</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Время активности</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Путь сохранения</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Завершено байт</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Огр. рейтинга</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Замечен целиком</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Активность</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Общий размер</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Пиры</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Загружено</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL трекера:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Обновляется…</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Работает</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Отключен</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Не соединился</translation>
    </message>
    <message>
        <source>#</source>
        <translation>№</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Н/Д</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Сиды</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Не работает</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Скопировать URL трекера</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Добавить новый трекер...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Править адрес трекера...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Редактирование трекера</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Личеры</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Удалить трекер</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Окно добавления трекеров</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Список трекеров для добавления (один трекер на строку):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 назад</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Резервирование места</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Приостановлен</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Завершён</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Перемещение</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Раздаётся</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Раздаётся</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>В очереди</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>С ошибкой</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Загружается</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Получение метаданных</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Проверяется</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Отсутствуют файлы</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>В очереди на проверку</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Загружается</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Проверка данных возобновления</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Простаивает</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Категории</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Ограничение скорости загрузки торрента</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Ограничение скорости отдачи торрента</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Возобновить</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Возобновить принудительно</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Ограничить рейтинг…</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Ограничить скорость отдачи…</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Ограничить скорость загрузки…</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Повысить</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Понизить</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Высший</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Низший</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Переместить…</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Копировать имя</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Копировать хеш</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Загружать с первой и последней части</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Автоматическое управление</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Категория</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Новая…</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Сбросить</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Приоритет</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Проверить принудительно</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Копировать магнет-ссылку</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Режим суперсида</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Переименовать…</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Загружать последовательно</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Проверить принудительно</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Новая категория</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Новое имя</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Установить расположение</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Переанонсировать принудительно</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Изменить категорию</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Путь сохранения</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Ограничение рейтинга загрузки/отдачи торрента</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Использовать глобальное ограничение раздачи</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Убрать ограничение раздачи</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Установить ограничение раздачи</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>рейтинг</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>минуты</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Продвинутый BitTorrent-клиент, написанный на C++. Использует фреймворк Qt и библиотеку libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Домашняя страница:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Форум:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Баг-трекер:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Подтверждение удаления</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Полностью удалить загруженные файлы с диска</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Подтверждение удаления - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Загрузить торренты по ссылкам</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Добавить ссылки на торренты</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>Б</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>КБ</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>МБ</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>ГБ</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>ТБ</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>ПБ</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>ЭБ</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/с</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 ч %2 мин</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 д %2 ч</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 мин</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 мин</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Путь сохранения пуст</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Путь плагина:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>Адрес или локальная папка</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Установить плагин</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Сиды:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Все плагины</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановлено</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Поисковые плагины…</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Все категории</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Поиск в:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Скопировать адрес описания</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Открыть страницу описания</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Показ результатов</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Только в именах торрентов</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Только включённые</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>вне</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Везде</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Установить новый плагин</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Вы можете получить новые поисковые плагины здесь:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Установленные поисковые плагины:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Включён</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Предупреждение: Обязательно соблюдайте законы об авторских правах вашей страны при загрузке торрентов из этих поисковых систем.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Проверить обновления</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Поисковые плагины</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Личеры</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Поисковый движок</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Сиды</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Включён</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
</context>
</TS>